@@ -1,27 +1,28 @@
 /*
-libelf.h - public header file for libelf.
-Copyright (C) 1995 - 2003 Michael Riepe <michael@stud.uni-hannover.de>
+ * libelf.h - public header file for libelf.
+ * Copyright (C) 1995 - 2006 Michael Riepe
+ * 
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ * 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public
-License as published by the Free Software Foundation; either
-version 2 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public
-License along with this library; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-*/
-
-/* @(#) $Id: libelf.h,v 1.14 2003/05/24 16:55:58 michael Exp $ */
+/* @(#) $Id: libelf.h,v 1.25 2006/08/18 00:00:38 michael Exp $ */
 
 #ifndef _LIBELF_H
 #define _LIBELF_H
 
+#include <stddef.h>	/* for size_t */
 #include <sys/types.h>
 
 #if __LIBELF_INTERNAL__
@@ -35,7 +36,7 @@ extern "C" {
 #endif /* __cplusplus */
 
 #ifndef __P
-# if __STDC__ || defined(__cplusplus)
+# if (__STDC__ + 0) || defined(__cplusplus) || defined(_WIN32)
 #  define __P(args) args
 # else /* __STDC__ || defined(__cplusplus) */
 #  define __P(args) ()
@@ -235,6 +236,25 @@ extern long elf64_checksum __P((Elf *__elf));
 
 #endif /* __LIBELF64 */
 
+/*
+ * ELF format extensions
+ *
+ * These functions return 0 on failure, 1 on success.
+ */
+extern int elf_getphnum(Elf *__elf, size_t *__resultp);
+extern int elf_getshnum(Elf *__elf, size_t *__resultp);
+extern int elf_getshstrndx(Elf *__elf, size_t *__resultp);
+
+/*
+ * Convenience functions
+ *
+ * elfx_update_shstrndx is elf_getshstrndx's counterpart.
+ * It should be used to set the e_shstrndx member.
+ * There is no update function for e_shnum or e_phnum
+ * because libelf handles them internally.
+ */
+extern int elfx_update_shstrndx(Elf *__elf, size_t __index);
+
 /*
  * Experimental extensions:
  *
